@@ -9,6 +9,12 @@
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
 #undef ENABLE_NLS
+#undef HAVE_ICONV
 #undef TRACE_FUNCTION
 #undef USE_NEW_STORAGE
 #undef USE_STATUS_MENU
+#undef NO_SCARY_EYEBALLS
+#undef USE_RUSSIAN
+#undef HAVE_LIBGDBM
+#undef HAVE_NDBM
+#undef GNOME_ICON
