@@ -14,16 +14,14 @@
 
 GtkWidget *frame;
 GtkWidget *frame_outline;
-GtkWidget *frame_outline2;
+/*GtkWidget *frame_outline2;*/
 GtkWidget *mess_label;
 GtkWidget *mess_pm;
 GtkWidget *applet;
 
 gboolean have_read_config = FALSE;
 
-static PanelOrientType orient;
-
-static char *cfnp;
+static void update_orient (PanelOrientType orient, int size);
 
 /*** Local function declarations ***/
 static gint applet_save_state_cb( GtkWidget *w, const char *privcfgpath, const char *globcfgpath, gpointer data );
@@ -31,49 +29,22 @@ static void applet_exposed_cb( GtkWidget *widget, gpointer data );
 static GtkWidget *create_applet( void );
 static void init_applet_signals( GtkWidget *window );
 static void applet_change_orient( GtkWidget *w, PanelOrientType o, gpointer data );
+void place_widgets (void);
+
+#ifdef HAVE_PANEL_PIXEL_SIZE
+static void applet_change_size( GtkWidget *w, int size, gpointer data );
+#endif
 
 /*** Global functions ***/
-void make_applet( int argc, char *argv[] )
+void make_applet( int argc, char *argv[], struct poptOption arguments[] )
 {
-	int cx;
-
 	GtkStyle *style;
-
-	static struct poptOption arguments[] =
-	{
-		{"uin", 'u', POPT_ARG_STRING, &cfnp, 0, N_("Use the defined UIN"), N_("UIN")},
-		{"noapplet", 'a', POPT_ARG_NONE, 0, 0, N_("startup without applet support"), NULL},
-		{NULL, 0, 0, NULL, 0, NULL, NULL}
-	};
-
 	GtkWidget *widget;
 
 #ifdef TRACE_FUNCTION
 	g_print( "make_applet\n" );
 #endif
 
-	toggles->applet = TRUE;
-
-	for( cx = 0; cx < argc; cx ++ )
-	{
-		if( !strcmp( "-a", argv[ cx ] ) ||
-		    !strcmp( "--noapplet", argv[ cx ] ) )
-			toggles->applet = FALSE;
-	}
-
-	if( toggles->applet == FALSE )
-		return;
-
-	cfnp = 0;
-	applet_widget_init( PACKAGE, VERSION, argc, argv,
-	                    arguments, 0, NULL );
-
-	if( cfnp )
-	{
-		g_free( configfilename );
-		configfilename = g_strdup_printf( "/GnomeICU_%s/", cfnp );
-	}
-
 	applet = applet_widget_new( PACKAGE );
 	if ( !applet )
 		g_error( _("Can't create applet!\n" ) );
@@ -84,6 +55,17 @@ void make_applet( int argc, char *argv[] )
 	gtk_widget_realize( applet );
 	init_pixmaps( style, applet );
 	widget = create_applet();
+
+/*	g_free(style);*/
+
+#ifdef HAVE_PANEL_PIXEL_SIZE
+	update_orient( applet_widget_get_panel_orient( APPLET_WIDGET( applet ) ),
+	               applet_widget_get_panel_pixel_size( APPLET_WIDGET( applet ) ) );
+#else
+	update_orient( applet_widget_get_panel_orient( APPLET_WIDGET( applet ) ),
+	               48 );
+#endif
+
 	gtk_widget_show( widget );
 
 	applet_widget_add( APPLET_WIDGET( applet ), widget );
@@ -94,7 +76,7 @@ void make_applet( int argc, char *argv[] )
 	                    GTK_SIGNAL_FUNC(applet_save_state_cb),
 	                    NULL);
 
-	gtk_signal_connect( GTK_OBJECT( applet ), "destroy",
+	gtk_signal_connect( GTK_OBJECT( applet ), "delete_event",
 	                    GTK_SIGNAL_FUNC( icq_quit ),
 	                    NULL );
 }
@@ -111,9 +93,18 @@ void applet_update( DWORD status, GdkPixmap *flash )
 
 	gchar *names_str = NULL;
 	gchar *temp;
+   	gchar *status_str;
 
 	GSList *contact;
 
+	gchar *nextmsg = NULL;
+
+	static gchar *old_tooltip = NULL;
+
+#ifdef TRACE_FUNCTION
+	g_print("applet_update\n");
+#endif
+
 	if( toggles->applet == FALSE )
 		return;
 
@@ -162,13 +153,17 @@ void applet_update( DWORD status, GdkPixmap *flash )
 
 	while( contact != NULL )
 	{
-		if( g_slist_length( ((CONTACT_PTR)contact->data)->stored_messages ) && !type )
-			type = ((STORED_MESSAGE_PTR)((CONTACT_PTR)contact->data)->stored_messages->data)->type;
-		num_messages += g_slist_length( ((CONTACT_PTR)contact->data)->stored_messages );
+		if( g_slist_length( kontakt->stored_messages ) && !type ) {
+			if( nextmsg == NULL )
+				nextmsg = g_strdup_printf( _("Next message from %s"), kontakt->nick );
+			type = ((STORED_MESSAGE_PTR)kontakt->stored_messages->data)->type;
+		}
+		num_messages += g_slist_length( kontakt->stored_messages );
 		contact = contact->next;
 	}
 
 	if( flash != NULL )
+		/* FIXME: I think the correct pixmap is in kontakt already */
 		switch( type )
 		{
 			case MESSAGE_CONT_LIST:
@@ -205,27 +200,50 @@ void applet_update( DWORD status, GdkPixmap *flash )
 		gtk_pixmap_set( GTK_PIXMAP( mess_pm ), status_pix,
 		                status_bit );
 
-
-	message_count = g_strdup_printf( "%d", num_messages );
-
-	gtk_label_set( GTK_LABEL( mess_label ), message_count );
-
 	/* adding code to display contacts in a tooltip, dwb 11-3-1999
 	   severely modified by Jeremy Wise, 11-10-1999 */
+   	/* Modified even more, by NH, to show status of contact  - NH*/
 
 	contact = Contacts;
 
 	while( contact != NULL )
 	{
-		if( ((CONTACT_PTR)contact->data)->status != STATUS_OFFLINE &&
-		    ((CONTACT_PTR)contact->data)->ignore_list != TRUE )
+		if( kontakt->status != STATUS_OFFLINE &&
+		    kontakt->ignore_list != TRUE )
 		{
 			/* Add nick to string */
 			temp = names_str;
+		   	switch (kontakt->status & 0xffff) {
+			case STATUS_ONLINE:
+				status_str = _("Online");
+				break;
+			case STATUS_AWAY:
+				status_str = _("Away");
+				break;
+			case STATUS_NA:
+				status_str = _("N/A");
+				break;
+			case STATUS_FREE_CHAT:
+				status_str = _("Free For Chat");
+				break;
+                        case STATUS_OCCUPIED:
+				status_str = _("Occupied");
+				break;
+                        case STATUS_DND:
+				status_str = _("Do Not Disturb");
+				break;
+                        case STATUS_INVISIBLE:
+				status_str = _("Invisible");
+				break;
+                        default:
+				status_str = _("Unknown");
+                        }
+                        
+			/* TODO: better use g_string_append( names_str... ) */
 			if( names_str )
-				names_str = g_strdup_printf( "%s%s\n", names_str, ((CONTACT_PTR)contact->data)->nick );
+				names_str = g_strdup_printf( "%s%s (%s)\n", names_str, kontakt->nick, status_str );
 			else
-				names_str = g_strdup_printf( "%s\n", ((CONTACT_PTR)contact->data)->nick );
+				names_str = g_strdup_printf( "%s (%s)\n", kontakt->nick, status_str );
 			g_free( temp );
 
 			online ++;
@@ -234,25 +252,47 @@ void applet_update( DWORD status, GdkPixmap *flash )
 	}
 
 	if ( num_messages == 0 )
-	/* [BV 27-Oct-99] show number of online contacts instead */
-	{
 		message_count = g_strdup_printf( "%d", online );
-		gtk_label_set( GTK_LABEL( mess_label ), message_count );
+	else
+		message_count = g_strdup_printf( "%d", num_messages );
+	gtk_label_set( GTK_LABEL( mess_label ), message_count );
+	g_free( message_count );
+
+	if( nextmsg == NULL )
+	{
+		if( names_str == NULL )
+			tooltips_str = g_strdup_printf( _("%u: 0 Users Online"), our_info->uin );
+		else if( online == 1 )
+			tooltips_str = g_strdup_printf( _("%u: %u User Online\n%s"), our_info->uin, online, names_str );
+		else
+			tooltips_str = g_strdup_printf( _("%u: %u Users Online\n%s"), our_info->uin, online, names_str );
+	}
+	else {
+		if( names_str == NULL )
+			tooltips_str = g_strdup_printf( _("%u: 0 Users Online\n%s"), our_info->uin, nextmsg );
+		else if( online == 1 )
+			tooltips_str = g_strdup_printf( _("%u: 1 User Online\n%s"), our_info->uin, nextmsg );
+		else
+			tooltips_str = g_strdup_printf( _("%u: %u Users Online\n%s"), our_info->uin, online, nextmsg );
+		g_free( nextmsg );
+		nextmsg = NULL;
 	}
 
-	if( names_str == NULL )
-		tooltips_str = g_strdup_printf( _("%u: 0 Users Online"), our_info->uin );
-	else if( online == 1 )
-		tooltips_str = g_strdup_printf( _("%u: %u User Online\n%s"), our_info->uin, online, names_str );
-	else
-		tooltips_str = g_strdup_printf( _("%u: %u Users Online\n%s"), our_info->uin, online, names_str );
+	g_free( names_str );
 
-	if( names_str )
-		g_free( names_str );
+        if (!toggles->hidetooltip) 
+        {
+		if( old_tooltip == NULL || strcmp( tooltips_str, old_tooltip ) )
+	                applet_widget_set_tooltip( APPLET_WIDGET( applet ), tooltips_str );
+		if( old_tooltip != NULL )
+			g_free( old_tooltip );
+		old_tooltip = g_strdup( tooltips_str );
+        }
+        else
+        {
+                applet_widget_set_tooltip( APPLET_WIDGET( applet ), NULL);
+        }
 
-	applet_widget_set_tooltip( APPLET_WIDGET( applet ), tooltips_str );
-
-	g_free( message_count );
 	g_free( tooltips_str );
 }
 
@@ -272,7 +312,7 @@ void applet_clicked_cb( GtkWidget *widget, GdkEventButton *ev, gpointer data )
 
 	contact = Contacts;
 
-	while( contact != NULL && g_slist_length( ((CONTACT_PTR)contact->data)->stored_messages ) == 0 )
+	while( contact != NULL && g_slist_length( kontakt->stored_messages ) == 0 )
 		contact = contact->next;
 
 	if( contact == NULL )
@@ -290,15 +330,30 @@ gboolean applet_hide_main( GtkWidget *widget, gpointer data )
 	if( !toggles->applet )
 		return TRUE;
 
-	if( !GTK_WIDGET_VISIBLE( app ) ) {
+        
+	if( !GTK_WIDGET_VISIBLE( app ) )
+	{
 		gtk_widget_show( app );
-	} else {
-		gtk_widget_hide( app );
-		if( autohide_timeout_tag ) {
-			gtk_timeout_remove( autohide_timeout_tag );
-			/* so we know it's not running anymore */
-			autohide_timeout_tag = 0;
-		}
+	}
+	else
+	{
+            if( (gnome_win_hints_get_workspace( app ) != gnome_win_hints_get_current_workspace()) && (GPOINTER_TO_INT(data) == 0))
+            {
+                gtk_widget_hide( app );
+                gdk_window_withdraw( GTK_WIDGET( app )->window );
+                gtk_widget_show( app );
+            }
+            else
+            {
+                gtk_widget_hide( app );
+                gdk_window_withdraw( GTK_WIDGET( app )->window );
+                if( autohide_timeout_tag )
+                {
+                    gtk_timeout_remove( autohide_timeout_tag );
+                    /* so we know it's not running anymore */
+                    autohide_timeout_tag = 0;
+                }
+            }
 	}
 	return TRUE; /* don't emit "destroy" signal */
 }
@@ -329,7 +384,6 @@ void applet_exposed_cb( GtkWidget *widget, gpointer data )
 
 GtkWidget *create_applet( void )
 {
-	GtkWidget *table;
 	GtkWidget *eventbox;
 
 #ifdef TRACE_FUNCTION
@@ -345,31 +399,25 @@ GtkWidget *create_applet( void )
 	gtk_widget_push_visual (gdk_imlib_get_visual ());
 	gtk_widget_push_colormap (gdk_imlib_get_colormap ());
 
-	table = gtk_table_new( 2, 1, FALSE );
 	eventbox = gtk_event_box_new();
 	frame_outline = gtk_frame_new( NULL );
-	frame_outline2 = gtk_frame_new( NULL );
+
 	gtk_container_add( GTK_CONTAINER( eventbox ), frame_outline );
 	
 	frame = gtk_fixed_new();
-	gtk_widget_set_usize( frame, 26, 44 );
 
-	gtk_container_add( GTK_CONTAINER( frame_outline ), frame_outline2 );
-	gtk_container_add( GTK_CONTAINER( frame_outline2 ), frame );
-	gtk_frame_set_shadow_type( GTK_FRAME( frame_outline ), GTK_SHADOW_IN );
-	gtk_frame_set_shadow_type( GTK_FRAME( frame_outline2 ), GTK_SHADOW_OUT );
-	gtk_widget_set_usize( frame_outline, 28, 48 );
+	gtk_container_add( GTK_CONTAINER( frame_outline ), frame );
+	gtk_frame_set_shadow_type( GTK_FRAME( frame_outline ), GTK_SHADOW_ETCHED_IN );
+	gtk_widget_set_usize( frame_outline, 20, 48 );
 	gtk_widget_show( frame_outline );
-	gtk_widget_show( frame_outline2 );
 
-	gtk_widget_show( table );
 	gtk_widget_show( frame );
 
 	gtk_fixed_put( GTK_FIXED( frame ), mess_pm, 2, 3 );
 	gtk_widget_show( mess_pm );
 
 	gtk_misc_set_alignment( GTK_MISC( mess_label ), 0.5, 0.5 );
-	gtk_fixed_put( GTK_FIXED( frame ), mess_label, 5, 22 );
+	gtk_fixed_put( GTK_FIXED( frame ), mess_label, 2, 30 );
 	gtk_widget_show( mess_label );
 
 	gtk_widget_pop_colormap ();
@@ -390,75 +438,84 @@ void init_applet_signals( GtkWidget *window )
 
 	gtk_signal_connect( GTK_OBJECT( window ), "change_orient",
 	                    GTK_SIGNAL_FUNC( applet_change_orient ), NULL );
-
+#ifdef HAVE_PANEL_PIXEL_SIZE
+	gtk_signal_connect( GTK_OBJECT( window ), "change_pixel_size",
+			    GTK_SIGNAL_FUNC( applet_change_size ), NULL );
+#endif
+        applet_widget_register_stock_callback_dir( APPLET_WIDGET( applet ),
+                                                   "set_status",
+                                                   GNOME_STOCK_MENU_REFRESH,
+                                                   _("Change Status") );
+        
 	applet_widget_register_stock_callback( APPLET_WIDGET( applet ),
-	                                       "about",
-	                                       GNOME_STOCK_MENU_ABOUT,
-	                                       _("About..."),
-	                                       (AppletCallbackFunc)about,
-	                                       NULL );
-	applet_widget_register_stock_callback( APPLET_WIDGET( applet ),
-	                                       "options",
-	                                       GNOME_STOCK_MENU_PROP,
-	                                       _("Options..."),
-	                                       (AppletCallbackFunc)configure_window,
-	                                       MainData );
-
-	applet_widget_register_stock_callback( APPLET_WIDGET( applet ),
-	                                       "set_online",
-	                                       "gnomeicu/gnomeicu-online.xpm",
+	                                       "set_status/set_online",
+	                                       GNOME_STOCK_MENU_BLANK,
 	                                       _("Online"),
 	                                       (AppletCallbackFunc)icq_set_status_online,
 	                                       MainData );
 
 	applet_widget_register_stock_callback( APPLET_WIDGET( applet ),
-	                                       "set_away",
-	                                       "gnomeicu/gnomeicu-away.xpm",
+	                                       "set_status/set_away",
+	                                       GNOME_STOCK_MENU_BLANK,
 	                                       _("Away"),
 	                                       (AppletCallbackFunc)icq_set_status_away,
 	                                       MainData );
 
 	applet_widget_register_stock_callback( APPLET_WIDGET( applet ),
-	                                       "set_na",
-	                                       "gnomeicu/gnomeicu-na.xpm",
+	                                       "set_status/set_na",
+	                                       GNOME_STOCK_MENU_BLANK,
 	                                       _("Not Available"),
 	                                       (AppletCallbackFunc)icq_set_status_na,
 	                                       MainData );
 
 	applet_widget_register_stock_callback( APPLET_WIDGET( applet ),
-	                                       "set_ffc",
-	                                       "gnomeicu/gnomeicu-ffc.xpm",
-	                                       _("Free for Chat"),
+	                                       "set_status/set_ffc",
+	                                       GNOME_STOCK_MENU_BLANK,
+	                                       _("Free For Chat"),
 	                                       (AppletCallbackFunc)icq_set_status_ffc,
 	                                       MainData );
 
 	applet_widget_register_stock_callback( APPLET_WIDGET( applet ),
-	                                       "set_occupied",
-	                                       "gnomeicu/gnomeicu-occ.xpm",
+	                                       "set_status/set_occ",
+	                                       GNOME_STOCK_MENU_BLANK,
 	                                       _("Occupied"),
 	                                       (AppletCallbackFunc)icq_set_status_occ,
 	                                       MainData );
 
 	applet_widget_register_stock_callback( APPLET_WIDGET( applet ),
-	                                       "set_dnd",
-	                                       "gnomeicu/gnomeicu-dnd.xpm",
+	                                       "set_status/set_dnd",
+	                                       GNOME_STOCK_MENU_BLANK,
 	                                       _("Do Not Disturb"),
 	                                       (AppletCallbackFunc)icq_set_status_dnd,
 	                                       MainData );
 
 	applet_widget_register_stock_callback( APPLET_WIDGET( applet ),
-	                                       "set_invisible",
-	                                       "gnomeicu/gnomeicu-inv.xpm",
+	                                       "set_status/set_inv",
+	                                       GNOME_STOCK_MENU_BLANK,
 	                                       _("Invisible"),
 	                                       (AppletCallbackFunc)icq_set_status_invisible,
 	                                       MainData );
-
+        
 	applet_widget_register_stock_callback( APPLET_WIDGET( applet ),
-	                                       "set_offline",
-	                                       "gnomeicu/gnomeicu-offline.xpm",
+	                                       "set_status/set_offline",
+	                                       GNOME_STOCK_MENU_BLANK,
 	                                       _("Offline"),
 	                                       (AppletCallbackFunc)icq_set_status_offline,
 	                                       MainData );
+        
+	applet_widget_register_stock_callback( APPLET_WIDGET( applet ),
+	                                       "options",
+	                                       GNOME_STOCK_MENU_PROP,
+	                                       _("Preferences..."),
+	                                       (AppletCallbackFunc)configure_window,
+	                                       MainData );
+
+	applet_widget_register_stock_callback( APPLET_WIDGET( applet ),
+	                                       "about",
+	                                       GNOME_STOCK_MENU_BLANK,
+	                                       _("About..."),
+	                                       (AppletCallbackFunc)about,
+	                                       NULL );
 
 	applet_widget_register_stock_callback( APPLET_WIDGET( applet ),
 	                                       "hide_show",
@@ -468,22 +525,74 @@ void init_applet_signals( GtkWidget *window )
 	                                       MainData );
 }
 
-static void applet_change_orient( GtkWidget *w, PanelOrientType o, gpointer data )
+static void
+update_orient (PanelOrientType orient, int size)
 {
-	orient = o;
+	gint x, y, size_minus;
 
-	if( orient == ORIENT_LEFT || orient == ORIENT_RIGHT )
+#ifdef TRACE_FUNCTION
+        g_print("update_orient orient: %d size: %d\n", orient, size);
+#endif
+
+        if (size < 36)
+            size_minus = 0;
+        else
+            size_minus = 4;
+        
+	if( orient == ORIENT_UP || orient == ORIENT_DOWN )
 	{
-		gtk_widget_set_usize( frame, 44, 26 );
-		gtk_widget_set_usize( frame_outline, 48, 28 );
-		gtk_fixed_move( GTK_FIXED( frame ), mess_label, 30, 2 );
+		if( size < 48 )
+		{
+			x = 48;
+			y = size - size_minus;
+		}
+		else
+		{
+			x = 24;
+			y = size - size_minus;
+		}
 	}
 	else
 	{
-		gtk_widget_set_usize( frame, 26, 44 );
-		gtk_widget_set_usize( frame_outline, 28, 48 );
-		gtk_fixed_move( GTK_FIXED( frame ), mess_label, 6, 22 );
+		if( size < 48 )
+		{
+			x = size;
+			y = 48;
+		}
+		else
+		{
+			x = size;
+			y = 24;
+		}
 	}
+
+	gtk_widget_set_usize( frame, x - size_minus, y - size_minus );
+	gtk_widget_set_usize( frame_outline, x, y );
+	if( x > y )
+		gtk_fixed_move( GTK_FIXED( frame ), mess_label, 30, 2 );
+	else
+		gtk_fixed_move( GTK_FIXED( frame ), mess_label, 6, 22 );
+}
+
+static void applet_change_orient( GtkWidget *w, PanelOrientType o, gpointer data )
+{
+	int size = 48;
+#ifdef HAVE_PANEL_PIXEL_SIZE
+	size = applet_widget_get_panel_pixel_size( APPLET_WIDGET( w ) );
+#endif
+	update_orient( o, size );
+}
+
+#ifdef HAVE_PANEL_PIXEL_SIZE
+static void applet_change_size( GtkWidget *w, int size, gpointer data )
+{
+	update_orient( applet_widget_get_panel_orient( APPLET_WIDGET( w )), size );
+}
+#endif
+
+void applet_remove( void )
+{
+	applet_widget_remove( APPLET_WIDGET( applet ));
 }
 
 void about( GtkWidget *widget, gpointer data )
@@ -491,7 +600,8 @@ void about( GtkWidget *widget, gpointer data )
 	GtkWidget *about;
 	const gchar *authors[] =
 	{
-		"Jeremy Wise <jwise@pathwaynet.com>",
+		"Jeremy Wise <jwise@pathwaynet.com> (jwise)",
+		"David Tabachnikov <captain@isdn.net.il> (nethunter)",
 		"As inspired by our Lord Jesus Christ",
 		NULL
 	};
@@ -501,7 +611,7 @@ void about( GtkWidget *widget, gpointer data )
 #endif
 
 	about = gnome_about_new( "GnomeICU", VERSION,
-	                         "(C) 1999 Jeremy Wise",
+	                         "(C) 1999-2001 Jeremy Wise",
 	                         authors,
 	                         _("GnomeICU is a small, fast and functional "
 	                         "clone of Mirabilis' ICQ program, specifically "
@@ -512,3 +622,11 @@ void about( GtkWidget *widget, gpointer data )
 
 	return;
 }
+
+/*
+ * Mainly stolen from gweather applet...
+ */
+void
+place_widgets ()
+{
+}
