@@ -17,7 +17,7 @@ void start_autohide_timeout_cb( GtkWidget *widget )
 	if ( !autohide_timeout_tag && GTK_WIDGET_VISIBLE( widget ) )
 	{
 		autohide_timeout_tag = gtk_timeout_add( autohide_time * 1000,
-							(GtkFunction) applet_hide_main, NULL);
+							(GtkFunction) applet_hide_main, GINT_TO_POINTER(1));
 	}
 }
 
