@@ -15,4 +15,4 @@ extern gboolean autohide_cbs_are_connected;
 void start_autohide_timeout_cb( GtkWidget *widget );
 void stop_autohide_timeout_cb( GtkWidget *widget );
 
-#endif __AUTOHIDE_H__
+#endif /* __AUTOHIDE_H__ */
