@@ -44,9 +44,10 @@ void change_info_window( GtkWidget *widget, gpointer data )
 	GtkWidget *scrollbar;
 	GtkAdjustment *adj, *adj2;
 
+   	struct tm birthday_tm;
+   	time_t birthday_t;
 	gchar *string;
 	GList *gender = NULL;
-	GList *months = NULL;
 
 	if( our_info->window == NULL )
 		our_info->window = gnome_property_box_new();
@@ -73,19 +74,6 @@ void change_info_window( GtkWidget *widget, gpointer data )
 	gender = g_list_prepend( gender, _("Female") );
 	gender = g_list_prepend( gender, _("Male") );
 
-	months = g_list_prepend( months, _("December") );
-	months = g_list_prepend( months, _("November") );
-	months = g_list_prepend( months, _("October") );
-	months = g_list_prepend( months, _("September") );
-	months = g_list_prepend( months, _("August") );
-	months = g_list_prepend( months, _("July") );
-	months = g_list_prepend( months, _("June") );
-	months = g_list_prepend( months, _("May") );
-	months = g_list_prepend( months, _("April") );
-	months = g_list_prepend( months, _("March") );
-	months = g_list_prepend( months, _("February") );
-	months = g_list_prepend( months, _("January") );
-
 /** General Tab **/
 
 	table = gtk_table_new( 5, 7, FALSE );
@@ -204,81 +192,21 @@ void change_info_window( GtkWidget *widget, gpointer data )
 	gtk_signal_connect( GTK_OBJECT( our_info->w_auth ), "toggled", changed, our_info->window );
 	gtk_widget_show( our_info->w_auth );
 
-	hbox = gtk_hbox_new( 0, FALSE );
-	gtk_table_attach( GTK_TABLE( table ), hbox, 1, 7, 4, 5, GTK_FILL, GTK_FILL,
-	                  5, 5 );
+   	our_info->w_birthday = gnome_date_edit_new(0, FALSE, TRUE);
 
-	our_info->w_birth_month = gtk_combo_new();
-	gtk_widget_set_usize( GTK_COMBO( our_info->w_birth_month )->entry, 85, 0 );
-	gtk_combo_set_popdown_strings( GTK_COMBO( our_info->w_birth_month ), months );
-
-	switch( our_info->birth_month )
-	{
-		case 1:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("January") );
-			break;
-		case 2:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("February") );
-			break;
-		case 3:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("March") );
-			break;
-		case 4:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("April") );
-			break;
-		case 5:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("May") );
-			break;
-		case 6:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("June") );
-			break;
-		case 7:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("July") );
-			break;
-		case 8:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("August") );
-			break;
-		case 9:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("September") );
-			break;
-		case 10:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("October") );
-			break;
-		case 11:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("November") );
-			break;
-		case 12:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("December") );
-			break;
-		default:
-			gtk_entry_set_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ), _("January") );
-	}
-
-	gtk_box_pack_start( GTK_BOX( hbox ), our_info->w_birth_month, FALSE, FALSE, 0 );
-	gtk_entry_set_editable( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ),
-	                        FALSE );
-	gtk_signal_connect( GTK_OBJECT( GTK_COMBO( our_info->w_birth_month )->entry ),
-	                    "changed", changed, our_info->window );
-	gtk_widget_show( our_info->w_birth_month );
-
-	our_info->w_birth_day = gtk_spin_button_new( adj, 0, 0 );
-	gtk_spin_button_set_wrap( GTK_SPIN_BUTTON( our_info->w_birth_day ), FALSE );
-	gtk_spin_button_set_shadow_type( GTK_SPIN_BUTTON( our_info->w_birth_day ),
-	                                 GTK_SHADOW_IN );
-	gtk_widget_set_usize( our_info->w_birth_day, 55, 0 );
-	gtk_box_pack_start( GTK_BOX( hbox ), our_info->w_birth_day, FALSE, FALSE, 0 );
-	gtk_widget_show( our_info->w_birth_day );
-
-	our_info->w_birth_year = gtk_spin_button_new( adj2, 0, 0 );
-	gtk_spin_button_set_wrap( GTK_SPIN_BUTTON( our_info->w_birth_year ), FALSE );
-	gtk_spin_button_set_shadow_type( GTK_SPIN_BUTTON( our_info->w_birth_year ),
-	                                 GTK_SHADOW_IN );
-	gtk_widget_set_usize( our_info->w_birth_year, 55, 0 );
-	gtk_box_pack_start( GTK_BOX( hbox ), our_info->w_birth_year, FALSE, FALSE, 0 );
-	gtk_widget_show( our_info->w_birth_year );
-
-	gtk_widget_show( hbox );
+	birthday_t = gnome_date_edit_get_date(GNOME_DATE_EDIT(our_info->w_birthday));
+   	birthday_tm = *localtime(&birthday_t);
+   	birthday_tm.tm_mon = our_info->birth_month;
+   	birthday_tm.tm_mday = our_info->birth_day;
+   	birthday_tm.tm_year = our_info->birth_year;
+   	gnome_date_edit_set_time(GNOME_DATE_EDIT(our_info->w_birthday), mktime(&birthday_tm));
 
+   	gtk_signal_connect( GTK_OBJECT( our_info->w_birthday ), "date-changed", changed, our_info->window );
+   
+   	gtk_widget_ref(our_info->w_birthday);
+   	gtk_table_attach(GTK_TABLE(table), our_info->w_birthday, 1, 2, 4, 5, GTK_FILL, GTK_FILL, 5, 5);
+   	gtk_widget_show(our_info->w_birthday);
+   
 	gtk_widget_show( table );
 
 /** Internet Tab **/
@@ -589,6 +517,9 @@ gint clear_window( GtkWidget *widget, gpointer data )
 
 void apply_changes( GtkWidget *widget, gpointer data )
 {
+   	time_t birthday_t;
+   	struct tm birthday_tm;
+   
 	g_free( our_info->nick );
 	our_info->nick = g_strdup( gtk_entry_get_text( GTK_ENTRY( our_info->w_nick ) ) );
 
@@ -609,35 +540,13 @@ void apply_changes( GtkWidget *widget, gpointer data )
 
 	our_info->auth = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON( our_info->w_auth ) );
 
-	our_info->birth_year = gtk_spin_button_get_value_as_int( GTK_SPIN_BUTTON( our_info->w_birth_year ) ) - 1900;
-
-	our_info->birth_day = gtk_spin_button_get_value_as_int( GTK_SPIN_BUTTON( our_info->w_birth_day ) );
-
-	if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("January") ) )
-		our_info->birth_month = 1;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("February") ) )
-		our_info->birth_month = 2;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("March") ) )
-		our_info->birth_month = 3;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("April") ) )
-		our_info->birth_month = 4;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("May") ) )
-		our_info->birth_month = 5;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("June") ) )
-		our_info->birth_month = 6;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("July") ) )
-		our_info->birth_month = 7;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("August") ) )
-		our_info->birth_month = 8;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("September") ) )
-		our_info->birth_month = 9;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("October") ) )
-		our_info->birth_month = 10;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("November") ) )
-		our_info->birth_month = 11;
-	else if( !strcmp( gtk_entry_get_text( GTK_ENTRY( GTK_COMBO( our_info->w_birth_month )->entry ) ), _("December") ) )
-		our_info->birth_month = 12;
-
+	birthday_t = gnome_date_edit_get_date(GNOME_DATE_EDIT(our_info->w_birthday));
+   	birthday_tm = *localtime(&birthday_t);
+   	our_info->birth_month = birthday_tm.tm_mon;
+   	our_info->birth_day = birthday_tm.tm_mday;
+   	our_info->birth_year = birthday_tm.tm_year;
+        g_print("%d %d %d\n", our_info->birth_month, our_info->birth_day, our_info->birth_year );
+   	
 	g_free( our_info->email );
 	our_info->email = g_strdup( gtk_entry_get_text( GTK_ENTRY( our_info->w_email ) ) );
 
