@@ -7,6 +7,10 @@
 /*** GnomeICU header files ***/
 #include "common.h"
 
+#ifdef GNOME_ICON
+#include <libgnomeui/gnome-window-icon.h>
+#endif
+
 typedef struct
 {
 	gpointer data;
@@ -52,7 +56,7 @@ void ChatWindowNew(ChatSession *csession)
 
      GtkTooltips *tooltip;
      GtkStyle *style;
-     gchar *wintitle;
+     gchar *wintitle_or_path;
 
 
 
@@ -62,9 +66,17 @@ void ChatWindowNew(ChatSession *csession)
 
 
      csession->chatwindow = gtk_window_new( GTK_WINDOW_TOPLEVEL );
-     wintitle = g_strdup_printf( _("GnomeICU: %s"), ( strlen( our_info->nick ) ? our_info->nick : _("User")));
-     gtk_window_set_title( GTK_WINDOW( csession->chatwindow ), wintitle );
-     g_free( wintitle );
+     wintitle_or_path = g_strdup_printf( _("GnomeICU: %s"), ( strlen( our_info->nick ) ? our_info->nick : _("User")));
+     gtk_window_set_title( GTK_WINDOW( csession->chatwindow ), wintitle_or_path );
+     g_free( wintitle_or_path );
+
+
+#ifdef GNOME_ICON
+     wintitle_or_path = make_file_path( "gnomeicu-chat.png" );
+     gnome_window_icon_set_from_file( GTK_WINDOW(csession->chatwindow), wintitle_or_path );
+     g_free( wintitle_or_path );
+#endif
+
      gtk_container_border_width( GTK_CONTAINER( csession->chatwindow ), 0 );
      gtk_window_set_default_size( GTK_WINDOW( csession->chatwindow ), 450, 400 );
      gtk_widget_realize( csession->chatwindow );
