@@ -36,6 +36,7 @@ static void entry_changed( GtkWidget *widget, gpointer data );
 static gint Build_Main_Window( void );
 static void theme_clist_select_row( GtkCList *clist, gint row, gint col,
                                     GdkEventButton *event, gpointer user_data );
+static void url_show_themes( GtkWidget *widget, gpointer data );
 
 /* Away Msg List */
 static void do_away_msgs(GtkWidget* main_window, GtkWidget*
@@ -359,6 +360,8 @@ void configure_window( GtkWidget *widget, gpointer data )
 	GtkWidget *toggle, *frame, *vbox;
         GtkWidget *theme_clist;
         GtkWidget *scrolled_window;
+	GtkWidget *theme_button;
+
 	/* Auto-Away/NA -- NH */
 	GtkWidget *autoaway_frame;
         GtkWidget *autoaway_table;
@@ -1837,6 +1840,13 @@ void configure_window( GtkWidget *widget, gpointer data )
 
         themes_fill_clist( theme_clist );
 
+	theme_button = gtk_button_new_with_label (_("Download Themes"));
+
+	gtk_box_pack_start (GTK_BOX (vbox), theme_button, FALSE, FALSE, 0);
+
+	gtk_signal_connect (GTK_OBJECT (theme_button), "clicked",
+	                    GTK_SIGNAL_FUNC (url_show_themes), NULL);
+
         gtk_signal_connect( GTK_OBJECT( theme_clist ), "select-row",
                             GTK_SIGNAL_FUNC( theme_clist_select_row ),
                             NULL );
@@ -2371,3 +2381,8 @@ void get_away_msg(GtkWidget *away_msg, gpointer data) {
       temp_away_msgs[index] =
          g_strdup(gtk_entry_get_text(GTK_ENTRY(away_msg)));
 }
+
+void url_show_themes( GtkWidget *widget, gpointer data )
+{
+	gnome_url_show ("http://gnomeicu.sourceforge.net/themes.php");
+}
