@@ -29,7 +29,6 @@ int stay_connected( void );
 void show_personal_info( GtkWidget *widget, gpointer data );
 void dump_personal_info( UIN_T uin );
 void authorize_uin( GtkWidget *widget, gpointer data );
-void search_window( GtkWidget *widget, gpointer data );
 void display_mess_history( GtkWidget *widget, gpointer data );
 void read_next( GtkWidget *widget, gpointer data );
 void send_chat_request( GtkWidget *widget, GtkWidget *entry );
@@ -63,7 +62,6 @@ gint app_save_state_cb( GnomeClient *client, gint phase,
 gint hide_ch_window( GtkWidget *widget, GdkEvent *event, GtkWidget *window );
 int popup_status_menu( GtkWidget *widget, gpointer data );
 gint ctrl_enter_cb( GtkWidget *widget, GdkEventKey *ev, int sock );
-void begin_search( GnomeDruidPage *page, GnomeDruid *druid );
 
 void request_file_action( GSList *completed_files );
 
