@@ -195,12 +195,13 @@ GtkWidget* create_ignore_list_window ( void )
 void modify_ignore_list( GtkWidget *widget, gpointer data )
 {
 	GtkCList *clist = GTK_CLIST( data );
-	gchar *nick;
+	gchar *uin;
 	int cx;
 
 	gint method = 0;
 
 	GSList *contact;
+	gboolean inlist;
 
 #ifdef TRACE_FUNCTION
 	g_print( "modify_ignore_list\n" );
@@ -210,17 +211,33 @@ void modify_ignore_list( GtkWidget *widget, gpointer data )
 	
 	while( contact != NULL )
 	{
-		kontakt->ignore_list = FALSE;
+		inlist = FALSE;
+		if (kontakt->ignore_list) {
+			for (cx = 0; cx < clist->rows; cx++) {
+				gtk_clist_get_text (clist, cx, 0, &uin);
+				if (atoi (uin) == kontakt->uin)
+					inlist = TRUE;
+			}
+			if (!inlist) {
+				if (kontakt->inlist == FALSE)
+					method |= UPDATE_NOTLIST;
+				else if (kontakt->status == STATUS_OFFLINE)
+					method |= UPDATE_OFFLINE;
+				else
+					method |= UPDATE_ONLINE;
+			}
+			kontakt->ignore_list = FALSE;
+		}
 		contact = contact->next;
 	}
 
 	for( cx = 0; cx < clist->rows; cx ++ )
 	{
-		gtk_clist_get_text( clist, cx, 0, &nick );
+		gtk_clist_get_text( clist, cx, 0, &uin );
 		contact = Contacts;
 		while( contact != NULL )
 		{
-			if( atoi( nick ) == kontakt->uin )
+			if( atoi( uin ) == kontakt->uin )
 			{
 				kontakt->ignore_list = TRUE;
 				kontakt->invis_list = TRUE;
