@@ -14,15 +14,17 @@ void snd_contact_list( void );
 void snd_login_1( void );
 void User_Offline( srv_net_icq_pak pak );
 void User_Online( srv_net_icq_pak pak );
+void Shortcut_Update( CONTACT_PTR contact );
+void Shortcut_Update_All( void );
 void Status_Update( srv_net_icq_pak pak );
 void Login( char *pass, int ip, int port );
 void ack_srv( DWORD seq );
 void Display_Info_Reply( srv_net_icq_pak pak );
 void Display_Search_Reply( srv_net_icq_pak pak );
-GSList *Do_Msg( const time_t msg_time, DWORD type, char *data, UIN_T uin,
+GSList *Do_Msg( time_t msg_time, DWORD type, char *data, UIN_T uin,
                 int message_type );
-GSList *Do_Chat( DWORD type, char *data, UIN_T uin, DWORD seq );
-GSList *Do_File( DWORD type, char *data, UIN_T uin, DWORD seq );
+ChatContact *Do_Chat( WORD sessionlen, char *data, UIN_T uin, DWORD seq, gchar *chatsession, int port );
+GSList *Do_File( char *data, UIN_T uin, DWORD seq, gchar *file_name, int file_size );
 void Display_Ext_Info_Reply( srv_net_icq_pak pak );
 void snd_invis_list( void );
 void snd_vis_list( void );
