@@ -13,6 +13,10 @@ gint found_list_compare_func( GtkCList *clist, gconstpointer ptrt,
                               gconstpointer ptr2 );
 void search_changed( GtkWidget *widget, gpointer data );
 void clear_i_window2( GtkWidget *widget, gpointer data );
+void begin_search (GnomeDruidPage *page, GnomeDruid *druid);
+void start_search (gchar *email, gchar *nick, gchar *first, gchar *last,
+                   UIN_T uin );
+void druid_cancel (GnomeDruid *druid, gpointer data);
 
 GtkWidget*
 create_AddContact (void)
@@ -55,7 +59,6 @@ create_AddContact (void)
 	GtkWidget *druid_vbox2;
 	GtkWidget *label74;
 	GtkWidget *scrolledwindow9;
-	GtkWidget *found_list;
 	GtkWidget *label75;
 	GtkWidget *label76;
 	GtkWidget *label77;
@@ -148,7 +151,7 @@ create_AddContact (void)
 	gtk_object_set_data_full (GTK_OBJECT (AddContact), "search_uin", search_uin,
 	                          (GtkDestroyNotify) gtk_widget_unref);
 	gtk_widget_show (search_uin);
-    gtk_widget_grab_focus( search_uin );
+	gtk_widget_grab_focus( search_uin );
 
 	gtk_signal_connect( GTK_OBJECT( search_uin ), "changed",
 	                    GTK_SIGNAL_FUNC( can_continue ),
@@ -393,9 +396,9 @@ create_AddContact (void)
 	gtk_clist_set_column_width (GTK_CLIST (found_list), 4, 110);
 	gtk_clist_column_titles_show (GTK_CLIST (found_list));
 
-	gtk_signal_connect (GTK_OBJECT (found_list), "destroy",
+/*	gtk_signal_connect (GTK_OBJECT (found_list), "destroy",
 	                    GTK_SIGNAL_FUNC (clear_i_window2), NULL);
-
+*/
 	gtk_object_set_data( GTK_OBJECT( found_list ), "druid", druid1 );
 
 	label75 = gtk_label_new (_("UIN"));
@@ -489,13 +492,14 @@ create_AddContact (void)
 	                                      GTK_SIGNAL_FUNC( begin_search ),
 	                                      NULL );
 
-	gtk_signal_connect_object( GTK_OBJECT( druidpagestandard1 ), "cancel",
-	                           GTK_SIGNAL_FUNC( gtk_widget_destroy ),
-	                           GTK_OBJECT( AddContact ) );
-	gtk_signal_connect_object( GTK_OBJECT( druidpagestandard2 ), "cancel",
-	                           GTK_SIGNAL_FUNC( gtk_widget_destroy ),
-	                           GTK_OBJECT( AddContact ) );
+	gtk_signal_connect( GTK_OBJECT( druid1 ), "cancel",
+	                           GTK_SIGNAL_FUNC( druid_cancel ),
+	                           AddContact );
 
+/*	gtk_signal_connect( GTK_OBJECT( druidpagestandard2 ), "cancel",
+	                           GTK_SIGNAL_FUNC( druid_cancel ),
+	                           AddContact );
+*/
 	gtk_signal_connect( GTK_OBJECT( druidpagestandard1 ), "next",
 	                    GTK_SIGNAL_FUNC( cant_continue ),
 	                    NULL );
@@ -723,7 +727,113 @@ void clear_i_window2( GtkWidget *widget, gpointer data )
 	if( contact != NULL )
 		kontakt->info->window = NULL;
 
-	if( New_Contact.uin == uin )*/
-		widget = NULL;
+	if( New_Contact.uin == uin )
+		widget = NULL;*/
 		New_Contact.info->window = NULL;
 }
+
+void search_window( GtkWidget *widget, gpointer data )
+{
+#ifdef TRACE_FUNCTION
+	g_print( "search_window\n" );
+#endif
+
+	gtk_widget_show( create_AddContact() );
+}
+
+void begin_search( GnomeDruidPage *page, GnomeDruid *druid )
+{
+	UIN_T uin;
+	gchar *nick, *first, *last, *email;
+	GtkEntry *entry;
+
+#ifdef TRACE_FUNCTION
+	g_print( "begin_search\n" );
+#endif
+
+	entry = gtk_object_get_data( GTK_OBJECT( page ), "search_uin" );
+	uin = atoi( gtk_entry_get_text( entry ) );
+	entry = gtk_object_get_data( GTK_OBJECT( page ), "search_nick" );
+	nick = gtk_entry_get_text( entry );
+	entry = gtk_object_get_data( GTK_OBJECT( page ), "search_first" );
+	first = gtk_entry_get_text( entry );
+	entry = gtk_object_get_data( GTK_OBJECT( page ), "search_last" );
+	last = gtk_entry_get_text( entry );
+	entry = gtk_object_get_data( GTK_OBJECT( page ), "search_email" );
+	email = gtk_entry_get_text( entry );
+
+	if( uin > 0 )
+		gnome_druid_set_buttons_sensitive( druid, TRUE, TRUE, TRUE );
+
+	found_list = GTK_WIDGET( gtk_object_get_data( GTK_OBJECT( page ), "found_list" ) );
+	gtk_clist_clear( GTK_CLIST( found_list ) );
+
+	start_search( email, nick, first, last, uin );
+}
+
+/* Start a Server Search for Information Specified */
+void start_search( gchar *email, gchar *nick,
+                   gchar* first, gchar* last,
+                   UIN_T uin )
+{
+	net_icq_pak pak;
+	int size;
+
+#ifdef TRACE_FUNCTION
+	g_print( "start_search\n" );
+#endif
+
+	if( uin > 0 )
+	{
+		start_new_info = TRUE;
+		show_info_new( uin );
+		return;
+	}
+
+	rus_conv(RUS_KOI_WIN, nick);
+	rus_conv(RUS_KOI_WIN, first);
+	rus_conv(RUS_KOI_WIN, last);
+    if( toggles->kanji ) {
+        nick = kanji_conv_auto( nick, KANJI_SJIS );
+        first = kanji_conv_auto( first, KANJI_SJIS );
+        last = kanji_conv_auto( last, KANJI_SJIS );
+    }
+	Word_2_Chars( pak.head.ver, ICQ_VER );
+	Word_2_Chars( pak.head.cmd, CMD_SEARCH_USER );
+	Word_2_Chars( pak.head.seq, seq_num++ );
+	DW_2_Chars( pak.head.UIN, our_info->uin );
+
+	size = 0;
+	Word_2_Chars( pak.data + size, strlen( nick ) + 1 );
+	size += 2;
+	strcpy( pak.data + size , nick );
+	size += strlen( nick ) + 1;
+	Word_2_Chars( pak.data + size, strlen( first ) + 1 );
+	size += 2;
+	strcpy( pak.data + size , first );
+	size += strlen( first ) + 1;
+	Word_2_Chars( pak.data + size, strlen( last ) + 1);
+	size += 2;
+	strcpy( pak.data + size , last );
+	size += strlen( last ) +1 ;
+	Word_2_Chars( pak.data + size, strlen( email ) + 1  );
+	size += 2;
+	strcpy( pak.data + size , email );
+	size += strlen( email ) + 1;
+
+	SOCKWRITE( &(pak.head.ver), size + sizeof( pak.head ) - 2, "CMD_SEARCH_USER");
+    if( toggles->kanji) {
+        g_free(nick);
+        g_free(first);
+        g_free(last);
+    }
+}
+
+void druid_cancel (GnomeDruid *druid, gpointer data)
+{
+	GnomeDruid *d = data;
+
+	gtk_widget_destroy (GTK_WIDGET (found_list));
+	found_list = NULL;
+	gtk_widget_destroy (GTK_WIDGET (d));
+}
