@@ -1,5 +1,5 @@
-GtkWidget* create_contact_list_window( UIN_T uin );
-GtkWidget* create_recd_contact_list_window( void );
+GtkWidget* create_contact_list_window( CONTACT_PTR contact );
+GtkWidget* create_recd_contact_list_window( CONTACT_PTR contact );
 
 void remove_contact_list_candidate( GtkWidget *widget, gpointer data );
 void info_list_candidate( GtkWidget *widget, gpointer data );
