@@ -460,64 +460,6 @@ void send_info_req( UIN_T uin )
 	SOCKWRITE( &(pak.head.ver), size + sizeof( pak.head ) - 2, "CMD_INFO_REQ");
 }
 
-/* Start a Server Search for Information Specified */
-void start_search( gchar *email, gchar *nick,
-                   gchar* first, gchar* last,
-                   UIN_T uin )
-{
-	net_icq_pak pak;
-	int size;
-
-#ifdef TRACE_FUNCTION
-	g_print( "start_search\n" );
-#endif
-
-	if( uin > 0 )
-	{
-		start_new_info = TRUE;
-		show_info_new( uin );
-		return;
-	}
-
-	rus_conv(RUS_KOI_WIN, nick);
-	rus_conv(RUS_KOI_WIN, first);
-	rus_conv(RUS_KOI_WIN, last);
-    if( toggles->kanji ) {
-        nick = kanji_conv_auto( nick, KANJI_SJIS );
-        first = kanji_conv_auto( first, KANJI_SJIS );
-        last = kanji_conv_auto( last, KANJI_SJIS );
-    }
-	Word_2_Chars( pak.head.ver, ICQ_VER );
-	Word_2_Chars( pak.head.cmd, CMD_SEARCH_USER );
-	Word_2_Chars( pak.head.seq, seq_num++ );
-	DW_2_Chars( pak.head.UIN, our_info->uin );
-
-	size = 0;
-	Word_2_Chars( pak.data + size, strlen( nick ) + 1 );
-	size += 2;
-	strcpy( pak.data + size , nick );
-	size += strlen( nick ) + 1;
-	Word_2_Chars( pak.data + size, strlen( first ) + 1 );
-	size += 2;
-	strcpy( pak.data + size , first );
-	size += strlen( first ) + 1;
-	Word_2_Chars( pak.data + size, strlen( last ) + 1);
-	size += 2;
-	strcpy( pak.data + size , last );
-	size += strlen( last ) +1 ;
-	Word_2_Chars( pak.data + size, strlen( email ) + 1  );
-	size += 2;
-	strcpy( pak.data + size , email );
-	size += strlen( email ) + 1;
-
-	SOCKWRITE( &(pak.head.ver), size + sizeof( pak.head ) - 2, "CMD_SEARCH_USER");
-    if( toggles->kanji) {
-        g_free(nick);
-        g_free(first);
-        g_free(last);
-    }
-}
-
 void send_ext_info_req( UIN_T uin )
 {
 	net_icq_pak pak;
