@@ -261,6 +261,12 @@ void Server_Response( srv_net_icq_pak pak, DWORD len, WORD cmd, WORD ver, WORD s
 			packet_print( pak.head.ver, s,
 	  		            PACKET_TYPE_UDP | PACKET_DIRECTION_RECEIVE, "SRV_END_OF_SEARCH" );
 			ack_srv( Chars_2_Word( pak.head.seq ) );
+			if (*(pak.head.ver+s-1) == 1)
+				gnome_ok_dialog (_("Not all matches could be retrieved."));
+			else if (*(pak.head.ver+s-2) == 6)
+				gnome_ok_dialog (_("No matches found."));
+			else
+				gnome_ok_dialog (_("Search complete."));
 			break;
 		case SRV_USER_FOUND:
 			packet_print( pak.head.ver, s,
