@@ -1560,7 +1560,6 @@ void TCPProcessPacket( BYTE *packet, int packet_length, int sock )
 					              PACKET_TYPE_TCP | PACKET_DIRECTION_RECEIVE, "FILE REQUEST" );
 			
 					contact = Do_File( message, pack_head.uin1, pack_tail.seq, pack_file.name, pack_file.size );
-					gnomeicu_event( EV_FILEREQ , kontakt->uin );
 					break;      
 
 				default:
@@ -1965,9 +1964,8 @@ int TCPFileReadServer(GIOChannel *source, GIOCondition condition, struct xfer_st
 		xfer->file_fd = open( ((struct file_struct*)xfer->file_queue->data)->full_filename, O_RDONLY, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH );
 		if( xfer->file_fd == -1 )
 		{
- 			next_file(xfer);
  			g_free(packet);
-			return TRUE;
+			return next_file(xfer);
 		}
 
 		lseek( xfer->file_fd, ((struct file_struct*)xfer->file_queue->data)->completed_bytes, SEEK_SET );
@@ -2014,11 +2012,19 @@ int TCPFileReadClient( GIOChannel *source, GIOCondition condition, struct xfer_s
                 return FALSE;
 
 	if (!xfer->packet_size) {
+		/* We have to turn off blocking for just a bit, or else
+		file transfers can get a bit flakey */
+
+		fcntl( xfer->sock_fd, F_SETFL, 0 );
+
 		if (read( xfer->sock_fd, (char*)(&xfer->packet_size), 2 ) != 2) {
 			cancel_transfer(0, xfer);
 			return FALSE;
 		}
 
+		/* Alright, don't block anymore */
+		fcntl( xfer->sock_fd, F_SETFL, 0 );
+
 		xfer->packet_size = GUINT16_FROM_LE (xfer->packet_size);
 
 		xfer->packet_offset = 0;
@@ -2065,7 +2071,8 @@ int TCPFileReadClient( GIOChannel *source, GIOCondition condition, struct xfer_s
 
 		case 0x02:
 			if (xfer->status == XFER_STATUS_TRANSFERING)
-				next_file(xfer);
+				if (!next_file(xfer))
+					return FALSE;
 
 			((struct file_struct *)xfer->file_queue->data)->short_filename = g_strdup(&xfer->packet[ 4 ]);
 			((struct file_struct *)xfer->file_queue->data)->total_bytes = Chars_2_DW(&xfer->packet[ 8 + strlen( &xfer->packet[4]) ]);
@@ -2192,6 +2199,8 @@ void file_place( struct xfer_struct *xfer )
 		gtk_signal_connect(GTK_OBJECT(filesel), "destroy", GTK_SIGNAL_FUNC(gtk_widget_destroy), NULL);
 		gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(filesel)->ok_button),
 		                   "clicked", GTK_SIGNAL_FUNC( save_incoming_file ), xfer );
+		gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(filesel)->cancel_button),
+		                   "clicked", GTK_SIGNAL_FUNC( cancel_transfer ), xfer );
 		gtk_signal_connect_object(GTK_OBJECT (GTK_FILE_SELECTION
 	 	                  (filesel)->cancel_button), "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy),
 	  	                 GTK_OBJECT( filesel ) );
@@ -2366,6 +2375,8 @@ int next_file( struct xfer_struct *xfer ) {
 	else
 		xfer->status = XFER_STATUS_CONNECTING;
 
+	xfer->completed_bytes += (completed_file->total_bytes - completed_file->completed_bytes);
+
 	if (xfer->direction == XFER_DIRECTION_SENDING)
 		TCPSendFileInfo( xfer );
 
