@@ -10,6 +10,7 @@
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 #include "datatype.h"
+#include "filexfer.h"
 
 #define TCP_VERSION 0x03
 
@@ -44,6 +45,72 @@
 
 extern const DWORD LOCALHOST;
 
+/*** File transfer defines ***/
+
+#define XFER_DIRECTION_SENDING		0
+#define XFER_DIRECTION_RECEIVING	1
+
+#define XFER_STATUS_PENDING		0
+#define XFER_STATUS_CONNECTING		1
+#define XFER_STATUS_TRANSFERING		2
+
+extern GSList *pending_xfers;
+
+struct file_struct {
+	char *short_filename;
+	char *full_filename;
+
+	guint total_bytes;
+	guint completed_bytes;
+
+	time_t start_time;
+};
+
+struct xfer_struct {
+	GSList *file_queue;
+	GSList *completed_files;
+
+	int sock_fd;
+	int file_fd;
+	GIOChannel *gioc;
+
+	int direction; 
+	CONTACT_PTR remote_contact;
+	DWORD seq;
+	int status;
+	WORD port;
+
+	filexferdlg *dialog;
+	gchar *filename;
+
+	int auto_transfer;
+	gchar *auto_save_path;
+
+	guint total_bytes;
+	guint completed_bytes;
+	time_t start_time;
+
+	char *packet;
+	unsigned short packet_offset;
+	unsigned short packet_size;
+};
+
+/* All TCP packets will have this information */
+typedef struct
+{
+	guint seq;
+	gchar *text;
+	BYTE *data;
+	UIN_T uin;
+	gint timeout;
+	gboolean sent;
+	GtkWidget *dialog;
+} tcp_message;
+
+tcp_message *tcp_prepare_message( CONTACT_PTR contact, BYTE *data,
+                                  gchar *text, gint seq,
+                                  gboolean prepend );
+
 int TCPGainConnection( DWORD ip, WORD port, GSList *contact );
 int TCPClearQueue( GSList *contact );
 
@@ -53,12 +120,12 @@ int TCPAcceptIncoming( gpointer data, int sock, GdkInputCondition cond );
 int TCPRetrieveAwayMessage( GSList *contact, gpointer data );
 int TCPRetrieveVersion( GSList *contact, gpointer data );
 
-int TCPAcceptFile( int sock, GSList *contact, DWORD seq );
-int TCPRefuseFile( int sock, DWORD seq );
-int TCPSendFileRequest( UIN_T uin, const gchar *msg, const gchar *file );
+int TCPAcceptFile( struct xfer_struct *xfer );
+int TCPRefuseFile( struct xfer_struct *xfer );
+int TCPSendFileRequest( UIN_T uin, const gchar *msg, GSList *files );
 
-void chat_save( GtkWidget *widget, gpointer data );
-void chat_save_got_name( GtkWidget *widget, gpointer data );
+void skip_file( GtkWidget *, struct xfer_struct *xfer);
+void cancel_transfer( GtkWidget *, struct xfer_struct *xfer);
 
 void TCPSendContactList( GtkWidget *widget, gpointer data );
 
