@@ -11,6 +11,9 @@ GList *get_time_zones( void );
 GList *get_country_codes( void );
 const gchar *Get_Country_Name( int code );
 const gchar *Get_Time_Zone_String( int code );
+GSList *get_contact_from_clist( void );
+void select_clist_row_from_contact( CONTACT_PTR contact );
+GtkCList *get_contact_clist( CONTACT_PTR contact );
 int Get_Country_Code( const gchar *country );
 int Get_Time_Zone( const gchar *desc );
 GdkPixmap *GetIcon_p( DWORD status );
@@ -22,7 +25,8 @@ WORD Chars_2_Word( const guchar buf[] );
 void DW_2_IP( guchar buf[], DWORD num );
 void DW_2_Chars( guchar buf[], DWORD num );
 void Word_2_Chars( guchar buf[], WORD num );
-void Add_User( UIN_T uin, const gchar *name, gboolean inlist );
+GSList * Find_User( UIN_T uin );
+GSList *Add_User( UIN_T uin, const gchar *name, gboolean inlist );
 void Init_New_User( void );
 
 #endif /* __UTIL_H__ */
