@@ -23,7 +23,7 @@ void icq_sendwebpresence( void )
 
 	pak.data[0] = 0x24;
 	pak.data[1] = 0x04;
-	pak.data[2] = 0x01; /* 00=Require auth, 01=Auth not req'd */
+	pak.data[2] = !our_info->auth; /* 00=Require auth, 01=Auth not req'd */
 	pak.data[3] = toggles->webpresence;
 	pak.data[4] = 0x01; /* Publish IP */
 
